@@ -20,7 +20,7 @@ has missing_after                  => 1800;
 has [qw(remove_after stuck_after)] => 172800;
 has tasks                          => sub { {} };
 
-our $VERSION = '10.11';
+our $VERSION = '10.12';
 
 sub add_task {
   my ($self, $name, $task) = @_;
@@ -217,7 +217,7 @@ Minion - Job queue
 
 L<Minion> is a high performance job queue for the Perl programming language, with support for multiple named queues,
 priorities, delayed jobs, job dependencies, job progress, job results, retries with backoff, rate limiting, unique
-jobs, job sequences, statistics, distributed workers, parallel processing, autoscaling, remote control,
+jobs, expiring jobs, statistics, distributed workers, parallel processing, autoscaling, remote control,
 L<Mojolicious|https://mojolicious.org> admin ui, resource leak protection and multiple backends (such as
 L<PostgreSQL|https://www.postgresql.org>).
 
@@ -517,6 +517,13 @@ defaults to C<1>.
 
 Delay job for this many seconds (from now), defaults to C<0>.
 
+=item expire
+
+  expire => 300
+
+Job is valid for this many seconds (from now) before it expires. Note that this option is B<EXPERIMENTAL> and might
+change without warning!
+
 =item notes
 
   notes => {foo => 'bar', baz => [1, 2, 3]}
@@ -544,13 +551,6 @@ Job priority, defaults to C<0>. Jobs with a higher priority get performed first.
 
 Queue to put job in, defaults to C<default>.
 
-=item sequence
-
-  sequence => 'host:mojolicious.org'
-
-Sequence this job belongs to. The previous job from the sequence will be automatically added as a parent to continue the
-sequence. Note that this option is B<EXPERIMENTAL> and might change without warning!
-
 =back
 
 =head2 foreground
@@ -661,12 +661,6 @@ List only jobs with one of these notes. Note that this option is B<EXPERIMENTAL>
 
 List only jobs in these queues.
 
-=item sequences
-
-  sequences => ['host:localhost', 'host:mojolicious.org']
-
-List only jobs from these sequences. Note that this option is B<EXPERIMENTAL> and might change without warning!
-
 =item states
 
   states => ['inactive', 'active']
@@ -715,6 +709,12 @@ Epoch time job was created.
 
 Epoch time job was delayed to.
 
+=item expires
+
+  expires => 784111777
+
+Epoch time job is valid until before it expires.
+
 =item finished
 
   finished => 784111777
@@ -727,12 +727,6 @@ Epoch time job was finished.
 
 Job id.
 
-=item next
-
-  next => 10024
-
-Next job in sequence.
-
 =item notes
 
   notes => {foo => 'bar', baz => [1, 2, 3]}
@@ -745,12 +739,6 @@ Hash reference with arbitrary metadata for this job.
 
 Jobs this job depends on.
 
-=item previous
-
-  previous => 10022
-
-Previous job in sequence.
-
 =item priority
 
   priority => 3
@@ -781,12 +769,6 @@ Epoch time job has been retried.
 
 Number of times job has been retried.
 
-=item sequence
-
-  sequence => 'host:mojolicious.org'
-
-Sequence name.
-
 =item started
 
   started => 784111777
