@@ -84,7 +84,8 @@ create index on minion_jobs using gin (notes);
 -- 20 up
 alter table minion_workers set unlogged;
 
--- 21 up
-alter table minion_jobs add column sequence text;
-alter table minion_jobs add column next bigint unique;
-create index on minion_jobs (sequence, next);
+-- 22 up
+alter table minion_jobs drop column if exists sequence;
+alter table minion_jobs drop column if exists next;
+alter table minion_jobs add column expires timestamp with time zone;
+create index on minion_jobs (expires);
